Crate opentalk_roomserver_types_livekit

Crate opentalk_roomserver_types_livekit 

Signaling data types for the OpenTalk livekit module.

Structs

Credentials
The current credentials of the livekit instance
LiveKitSettings
LiveKit settings.
LiveKitState
Signaling event to pass information about the livekit server around
MicrophoneRestrictionError
Internal error that can occur when updating the microphone restriction state
ParticipantsMuted
Participants were muted by a moderator

Enums

LiveKitCommand
The livekit command variants
LiveKitError
Livekit errors
LiveKitEvent
The events emitted for livekit
LiveKitInternal
Internal LiveKit commands that can be sent by other modules
MicrophoneRestrictionErrorKind
The type of error that can occur when updating the microphone restriction state
MicrophoneRestrictionState
Moderation module state that is visible only to moderators

Constants

LIVEKIT_MODULE_ID
The module id for the signaling module